KeyConfig class

Represents values from JsonKey when merged with local configuration.

Constructors

KeyConfig({required Object? defaultValue, required bool disallowNullValue, required bool ignore, required bool includeIfNull, required String name, required bool required, required Object? unknownEnumValue})

Properties

defaultValue → Object?
final
disallowNullValue → bool
final
hashCode → int
The hash code for this object.
no setterinherited
ignore → bool
final
includeIfNull → bool
final
name → String
final
required → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknownEnumValue → Object?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited